VideoEncoderConfig

Struct VideoEncoderConfig 

pub struct VideoEncoderConfig {
    pub codec: VideoCodec,
    pub width: Option<u32>,
    pub height: Option<u32>,
    pub fps: Option<f64>,
    pub bitrate_mode: BitrateMode,
    pub pixel_format: Option<PixelFormat>,
    pub codec_options: Option<VideoCodecOptions>,
}
Configuration for the video stream of an export preset.

Fields with Option type are not applied to the builder when None, allowing the builder’s existing values (or defaults) to be preserved.

Fields

codec: VideoCodec

Video codec.

width: Option<u32>

Output width in pixels. None = preserve source width.

height: Option<u32>

Output height in pixels. None = preserve source height.

fps: Option<f64>

Output frame rate. None = preserve source frame rate.

bitrate_mode: BitrateMode

Bitrate control mode.

pixel_format: Option<PixelFormat>

Optional pixel format override. None lets the encoder choose.

codec_options: Option<VideoCodecOptions>

Optional per-codec advanced options.